summaryrefslogtreecommitdiffstats
path: root/thumbs.c
diff options
context:
space:
mode:
authorBerke Kocaoğlu <berke.kocaoglu@metu.edu.tr>2021-09-16 11:32:59 +0200
committerBerke Kocaoğlu <berke.kocaoglu@metu.edu.tr>2021-09-16 21:55:31 +0200
commit7cce7ea857321c854fc9e061edee3a32f4831d18 (patch)
treed8ad4f168d67a433278912a8d07231760aff5cbc /thumbs.c
parent9c73646d9c709005301d5be93d0232d89201b21e (diff)
downloadnsxiv-7cce7ea857321c854fc9e061edee3a32f4831d18.tar.zst
Rename, Update Docs and Prepare for Release (#9)
Co-authored-by: Guilherme Rugai Freire <41879254+GRFreire@users.noreply.github.com> Co-authored-by: N-R-K <79544946+N-R-K@users.noreply.github.com> Co-authored-by: NRK <nrk@disroot.org> Co-authored-by: Arthur Williams <taaparthur@gmail.com> Co-authored-by: eylles <ed.ylles1997@gmail.com>
Diffstat (limited to 'thumbs.c')
-rw-r--r--thumbs.c17
1 files changed, 9 insertions, 8 deletions
diff --git a/thumbs.c b/thumbs.c
index 3aa03fb..1850f52 100644
--- a/thumbs.c
+++ b/thumbs.c
@@ -1,22 +1,22 @@
/* Copyright 2011 Bert Muennich
*
* This file is part of sxiv.
*
* sxiv is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published
* by the Free Software Foundation; either version 2 of the License,
* or (at your option) any later version.
*
* sxiv is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with sxiv. If not, see <http://www.gnu.org/licenses/>.
+ * along with nsxiv. If not, see <http://www.gnu.org/licenses/>.
*/
-#include "sxiv.h"
+#include "nsxiv.h"
#define _THUMBS_CONFIG
#include "config.h"
@@ -172,10 +172,11 @@ void tns_init(tns_t *tns, fileinfo_t *files, const int *cnt, int *sel,
dsuffix = "/.cache";
}
if (homedir != NULL) {
+ const char *s = "/nsxiv";
free(cache_dir);
- len = strlen(homedir) + strlen(dsuffix) + 6;
+ len = strlen(homedir) + strlen(dsuffix) + strlen(s) + 1;
cache_dir = (char*) emalloc(len);
- snprintf(cache_dir, len, "%s%s/sxiv", homedir, dsuffix);
+ snprintf(cache_dir, len, "%s%s%s", homedir, dsuffix, s);
} else {
error(0, 0, "Cache directory not found");
}
@@ -272,7 +273,7 @@ bool tns_load(tns_t *tns, int n, bool force, bool cache_only)
ExifContent *ifd;
ExifByteOrder byte_order;
int tmpfd;
- char tmppath[] = "/tmp/sxiv-XXXXXX";
+ char tmppath[] = "/tmp/nsxiv-XXXXXX";
Imlib_Image tmpim;
if ((ed = exif_data_new_from_file(file->path)) != NULL) {
@@ -1,22 +1,22 @@
/* Copyright 2011 Bert Muennich
*
- * This file is part of sxiv.
+ * This file is a part of nsxiv.
*
@@ -1,22 +1,22 @@
*
- * sxiv is free software; you can redistribute it and/or modify
+ * nsxiv is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published
* by the Free Software Foundation; either version 2 of the License,
@@ -1,22 +1,22 @@
* or (at your option) any later version.
*
- * sxiv is distributed in the hope that it will be useful,
+ * nsxiv is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the